@@ -1,5 +1,5 @@
 package Net::Kubernetes::Role::APIAccess;
-$Net::Kubernetes::Role::APIAccess::VERSION = '1.07';
+$Net::Kubernetes::Role::APIAccess::VERSION = '1.08';
 # ABSTRACT: Role allowing direct access to the REST api
 
 use Moose::Role;
@@ -170,7 +170,7 @@ sub _build_lwp_agent {
     if ($self->ssl_cert_file) {
         for my $key (qw(SSL_cert_file SSL_key_file SSL_ca_file)) {
             my $method_name = lc($key);
-            $ua_args{$key} = $self->$method_name;
+            $ua_args{ssl_opts}{$key} = $self->$method_name;
         }
     }
 
@@ -270,7 +270,7 @@ Net::Kubernetes::Role::APIAccess - Role allowing direct access to the REST api
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 AUTHOR
 
